==> linshare-core-1.6.1-src.tar.bz2: src/main/java/org/linagora/linshare/core/facade/webservice/admin/impl/AdminGenericFacadeImpl.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2014 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2014. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.facade.webservice.admin.impl;

import org.linagora.linshare.core.domain.constants.Role;
import org.linagora.linshare.core.domain.entities.User;
import org.linagora.linshare.core.exception.BusinessErrorCode;
import org.linagora.linshare.core.exception.BusinessException;
import org.linagora.linshare.core.facade.webservice.admin.AdminGenericFacade;
import org.linagora.linshare.core.facade.webservice.user.impl.GenericFacadeImpl;
import org.linagora.linshare.core.service.AccountService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class AdminGenericFacadeImpl extends GenericFacadeImpl implements
		AdminGenericFacade {

	private static final Logger logger = LoggerFactory
			.getLogger(AdminGenericFacadeImpl.class);

	public AdminGenericFacadeImpl(final AccountService accountService) {
		super(accountService);
	}

	@Override
	public User checkAuthentication(Role role) throws BusinessException {
		User user = super.checkAuthentication();

		if (role != Role.SUPERADMIN && role != Role.ADMIN) {
			logger.error("Programmatic error: role must be set either to SUPERADMIN or ADMIN but is " + role.name());
			throw new IllegalArgumentException(
					"role must be either SUPERADMIN or ADMIN");
		}
		// user as at least admin role 
		if (user.getRole().toInt() < role.toInt())
			throw new BusinessException(
					BusinessErrorCode.WEBSERVICE_FORBIDDEN,
					"You are not authorized to use this service");
		return user;
	}
}

==> linshare-core-1.7.8-src.tar.bz2: src/main/java/org/linagora/linshare/core/facade/webservice/admin/impl/AdminGenericFacadeImpl.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2014 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2014. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.facade.webservice.admin.impl;

import org.linagora.linshare.core.domain.constants.Role;
import org.linagora.linshare.core.domain.entities.User;
import org.linagora.linshare.core.exception.BusinessErrorCode;
import org.linagora.linshare.core.exception.BusinessException;
import org.linagora.linshare.core.facade.webservice.admin.AdminGenericFacade;
import org.linagora.linshare.core.facade.webservice.user.impl.GenericFacadeImpl;
import org.linagora.linshare.core.service.AccountService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class AdminGenericFacadeImpl extends GenericFacadeImpl implements
		AdminGenericFacade {

	private static final Logger logger = LoggerFactory
			.getLogger(AdminGenericFacadeImpl.class);

	public AdminGenericFacadeImpl(final AccountService accountService) {
		super(accountService);
	}

	@Override
	public User checkAuthentication(Role role) throws BusinessException {
		User actor = super.checkAuthentication();

		if (role != Role.SUPERADMIN && role != Role.ADMIN) {
			logger.error("Programmatic error: role must be set either to SUPERADMIN or ADMIN but is " + role.name());
			throw new IllegalArgumentException(
					"role must be either SUPERADMIN or ADMIN");
		}
		if (!(actor.hasAdminRole() || actor.hasSuperAdminRole())) {
			logger.error("Current actor is trying to access to a forbbiden api : " + actor.getAccountReprentation());
			throw new BusinessException(
					BusinessErrorCode.WEBSERVICE_FORBIDDEN,
					"You are not authorized to use this service");
		}
		if (role.equals(Role.SUPERADMIN)) {
			if (!(actor.hasSuperAdminRole())) {
				logger.error("Current actor is trying to access to a forbbiden api : " + actor.getAccountReprentation());
				throw new BusinessException(
						BusinessErrorCode.WEBSERVICE_FORBIDDEN,
						"You are not authorized to use this service");
			}
		}
		return actor;
	}
}
